==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/mdfe/__openerp__.py <==
# -*- coding: utf-8 -*-
#
# Copyright (C) 2009-2019 All Rights Reserved. Luiz Fernando Maciel Franca
#               www.siginformatica.com.br <luiz@siginformatica.com.br>
#                                 -------
#
# Copyleft (CC) 2019, Creative Commons
# ================================================================================
# Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
# http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
# ================================================================================
# noinspection PyStatementEffect
{
    'name': 'Manifesto Eletrônico de Documentos Fiscais',
    'version': '7.0.21.12.14',
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'category': 'Fiscal',
    'summary': 'MDF-e, CT-e, NF-e, Documentos Fiscais',
    'description': """
Manifesto Eletrônico de Documentos Fiscais
===========================
É um modelo nacional de documento fiscal eletrônico com validade jurídica garantida pela assinatura
digital do emitente, que simplifica as obrigações acessórias dos contribuintes e permite, ao mesmo
tempo, o acompanhamento em tempo real das prestações e operações comerciais pelo Fisco.

O **MDF-e** deverá ser emitido pelos contribuintes emitentes de CT-e, no transporte de cargas
fracionadas e lotação, ou pelos contribuintes emitentes de NF-e no transporte interestadual de bens
ou mercadorias, realizado em veículos próprios ou arrendados, ou mediante contratação de
transportador autônomo de cargas.

Dentre as finalidades do MDF-e destacam-se:
------------------------------------------
1. Permitir o rastreamento da circulação física da carga;
2. Identificar o responsável pelo transporte a cada trecho do percurso;
3. Consolidar as informações da carga acobertadas por um único CT-e ou NF-e;
4. Agilizar o registro em lote de documentos fiscais em trânsito;
5. Registrar as alterações/substituições das unidades de transporte ou de carga e seus condutores;
6. Registrar o momento do início e do fim do transporte.""",
    'depends': ['fiscal', 'veiculos'],
    'data': [
        # Security
        'security/res.groups.csv',  # Grupos usuario/gerente (user/manager) do modulo MDF-e
        'security/ir.model.access.csv',  # Permissoes

        # Inherit
        'inherit/fiscal/data/modelo_nf.xml',  # Modelo 58 (Inclusao)
        'inherit/fiscal/data/modelo_nf_series.xml',  # Controle de numeracao/serie do modelo 58
        'inherit/fiscal/data/parametro.xml',  # modelo 58 e demais valores no parametro do Fiscal
        'inherit/fiscal/views/parametro_view.xml',  # Aba MDF-e no parametro do Fiscal
        'inherit/veiculos/views/veiculo_view.xml',
        'inherit/veiculos/views/reboque_view.xml',
        'inherit/adm/pessoa/views/proprietario_veiculo_view.xml',

        # Views, Action & Menu
        'views/mdfe_modal_rodoviario_view.xml',
        'views/mdfe_referencia_nfe_view.xml',   # NF-e referenciadas (informacoes dos documentos)
        'views/mdfe_referencia_nf_view.xml',  # NF (01 e A1) referenciadas (inf. dos documentos)
        'views/mdfe_municipio_descarrega_view.xml',
        'views/action.xml',
        'views/menu.xml',

        # Wizards
        'wizard/damdfe_osv_view.xml',
        'wizard/cancelamento_osv_view.xml',
    ],
    'license': 'Other proprietary',
    "application": True,
    'installable': True,
    'active': False,
}

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/mdfe/__openerp__.py <==
# -*- coding: utf-8 -*-
#
# Copyright (C) 2009-2019 All Rights Reserved. Luiz Fernando Maciel Franca
#               www.siginformatica.com.br <luiz@siginformatica.com.br>
#                                 -------
#
# Copyleft (CC) 2019, Creative Commons
# ================================================================================
# Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
# http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
# ================================================================================
# noinspection PyStatementEffect
{
    'name': 'Manifesto Eletrônico de Documentos Fiscais',
    'version': '7.0.2310.2',
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'category': 'Fiscal',
    'summary': 'MDF-e, CT-e, NF-e, Documentos Fiscais',
    'description': """
Manifesto Eletrônico de Documentos Fiscais
===========================
É um modelo nacional de documento fiscal eletrônico com validade jurídica garantida pela assinatura
digital do emitente, que simplifica as obrigações acessórias dos contribuintes e permite, ao mesmo
tempo, o acompanhamento em tempo real das prestações e operações comerciais pelo Fisco.

O **MDF-e** deverá ser emitido pelos contribuintes emitentes de CT-e, no transporte de cargas
fracionadas e lotação, ou pelos contribuintes emitentes de NF-e no transporte interestadual de bens
ou mercadorias, realizado em veículos próprios ou arrendados, ou mediante contratação de
transportador autônomo de cargas.

Dentre as finalidades do MDF-e destacam-se:
------------------------------------------
1. Permitir o rastreamento da circulação física da carga;
2. Identificar o responsável pelo transporte a cada trecho do percurso;
3. Consolidar as informações da carga acobertadas por um único CT-e ou NF-e;
4. Agilizar o registro em lote de documentos fiscais em trânsito;
5. Registrar as alterações/substituições das unidades de transporte ou de carga e seus condutores;
6. Registrar o momento do início e do fim do transporte.""",
    'depends': ['fiscal', 'veiculos'],
    'data': [
        # Security
        'security/res.groups.csv',  # Grupos usuario/gerente (user/manager) do modulo MDF-e
        'security/ir.model.access.csv',  # Permissoes

        # Inherit
        'inherit/fiscal/data/modelo_nf.xml',  # Modelo 58 (Inclusao)
        'inherit/fiscal/data/modelo_nf_series.xml',  # Controle de numeracao/serie do modelo 58
        'inherit/fiscal/data/parametro.xml',  # modelo 58 e demais valores no parametro do Fiscal
        'inherit/fiscal/views/parametro_view.xml',  # Aba MDF-e no parametro do Fiscal
        'inherit/veiculos/views/veiculo_view.xml',
        'inherit/veiculos/views/reboque_view.xml',
        'inherit/adm/pessoa/views/proprietario_veiculo_view.xml',

        # Views, Action & Menu
        'views/mdfe_modal_rodoviario_view.xml',
        'views/mdfe_referencia_nfe_view.xml',   # NF-e referenciadas (informacoes dos documentos)
        'views/mdfe_referencia_nf_view.xml',  # NF (01 e A1) referenciadas (inf. dos documentos)
        'views/mdfe_municipio_descarrega_view.xml',
        'views/action.xml',
        'views/menu.xml',

        # Wizards
        'wizard/damdfe_osv_view.xml',
        'wizard/cancelamento_osv_view.xml',
    ],
    'license': 'Other proprietary',
    "application": True,
    'installable': True,
    'active': False,
}

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
